package com.fs.qw.service;


import com.baomidou.mybatisplus.extension.service.IService;
import com.fs.qw.domain.CustomerTransferApprovalQw;

import java.util.List;

/**
 * 客户转移审批-企微的Service接口
 *
 * @author fs
 * @date 2025-10-24
 */
public interface ICustomerTransferApprovalQwService extends IService<CustomerTransferApprovalQw> {
    /**
     * 查询客户转移审批-企微的
     *
     * @param id 客户转移审批-企微的主键
     * @return 客户转移审批-企微的
     */
    CustomerTransferApprovalQw selectCustomerTransferApprovalQwById(Long id);

    /**
     * 查询客户转移审批-企微的列表
     *
     * @param customerTransferApprovalQw 客户转移审批-企微的
     * @return 客户转移审批-企微的集合
     */
    List<CustomerTransferApprovalQw> selectCustomerTransferApprovalQwList(CustomerTransferApprovalQw customerTransferApprovalQw);

    /**
     * 新增客户转移审批-企微的
     *
     * @param customerTransferApprovalQw 客户转移审批-企微的
     * @return 结果
     */
    int insertCustomerTransferApprovalQw(CustomerTransferApprovalQw customerTransferApprovalQw);

    /**
     * 修改客户转移审批-企微的
     *
     * @param customerTransferApprovalQw 客户转移审批-企微的
     * @return 结果
     */
    int updateCustomerTransferApprovalQw(CustomerTransferApprovalQw customerTransferApprovalQw);

    /**
     * 批量删除客户转移审批-企微的
     *
     * @param ids 需要删除的客户转移审批-企微的主键集合
     * @return 结果
     */
    int deleteCustomerTransferApprovalQwByIds(Long[] ids);

    /**
     * 删除客户转移审批-企微的信息
     *
     * @param id 客户转移审批-企微的主键
     * @return 结果
     */
    int deleteCustomerTransferApprovalQwById(Long id);

    /**
     * 自动审批通过
     */
    public void autoApprovePassQw();
}
